summaryrefslogtreecommitdiffstats
path: root/korganizer/calendarview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/calendarview.cpp')
-rw-r--r--korganizer/calendarview.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/korganizer/calendarview.cpp b/korganizer/calendarview.cpp
index 2f31310b..77f8f80b 100644
--- a/korganizer/calendarview.cpp
+++ b/korganizer/calendarview.cpp
@@ -537,10 +537,10 @@ void CalendarView::readSettings()
TQString str;
// read settings from the KConfig, supplying reasonable
// defaults where none are to be found
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
#ifndef KORG_NOSPLITTER
config->setGroup( "KOrganizer Geometry" );
@@ -577,7 +577,7 @@ void CalendarView::writeSettings()
{
// kdDebug(5850) << "CalendarView::writeSettings" << endl;
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
#ifndef KORG_NOSPLITTER
config->setGroup( "KOrganizer Geometry" );
@@ -602,7 +602,7 @@ void CalendarView::writeSettings()
config->sync();
}
-void CalendarView::readFilterSettings( KConfig *config )
+void CalendarView::readFilterSettings( TDEConfig *config )
{
// kdDebug(5850) << "CalendarView::readFilterSettings()" << endl;
@@ -639,7 +639,7 @@ void CalendarView::readFilterSettings( KConfig *config )
updateFilter();
}
-void CalendarView::writeFilterSettings( KConfig *config )
+void CalendarView::writeFilterSettings( TDEConfig *config )
{
// kdDebug(5850) << "CalendarView::writeFilterSettings()" << endl;
@@ -537,10 +537,10 @@ void CalendarView::readSettings()
TQString str;
- // read settings from the KConfig, supplying reasonable
+ // read settings from the TDEConfig, supplying reasonable
// defaults where none are to be found